/**
 * \file Instrument.h
 * \brief contains common definitions of data structures shared by the various operators, stages and connectors
 * \author Ray Garcia <rayg@ssec.wisc.edu>, Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 *  \version $Id: Instrument.h,v 1.17 2005/07/08 07:12:52 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details..
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */

/// \mainpage
/// The common package contains utility classes, definitions and declarations 
/// used throughout the rest of the GIPS codebase.

#ifndef H_INSTRUMENT
#define H_INSTRUMENT

#ifndef NO_DEPENDENCY_INCLUDES
#include <complex>
#include <string>
#include <blitz/array.h>
#endif

using namespace std;
namespace gips
{
    
    namespace instrument
    {
	typedef char uuid_t[16]; // 128 bits of unique identifier goodness.
	enum ObservationType {SCENE, HOT, AMBIENT, SPACE, INVALID};
	enum Band {LW, MW, SW, SMW};
	enum PipelineSelector {SHIS_V0, GIFTS_V0};
	enum ScanDirection {FW, BW};
	typedef unsigned int pixel_t;
	typedef long int observation_id_t;
	typedef long int cal_context_id;
		
	int getBandSize(const string&, const string&);
	int getBandFoldPoint(const string&, const string&);
	ScanDirection getScanDir(const string&);
	string scanDirStr(ScanDirection);
	ObservationType getObsType(const string&);
	

	struct band_t
	{
	    const blitz::Array<double,1> wavenumbers;
	    const int size;
	    const int foldPoint; 
	    
	    band_t(const blitz::Array<double,1>& wn, const int &fp): wavenumbers(wn), size(wn.size()), foldPoint(fp) {};
	};
        
	typedef unsigned int DetectorIndex_t;
	
	typedef blitz::Array<float,1> BlitzRealFloatVector;
	typedef blitz::Array<double,1> BlitzRealDoubleVector;
	
	typedef blitz::Array<complex<float>,1> BlitzCplxFloatVector;
	typedef blitz::Array<complex<double>,1> BlitzCplxDoubleVector;
	
	typedef blitz::Array<complex<float>,2> BlitzCplxFloatMatrix;
	typedef blitz::Array<complex<double>,2> BlitzCplxDoubleMatrix;
	
	
    } // namespace instrument

    
} // namespace gips
    
#endif

