/**
 * \file Ifg2Spectrum.h
 * \brief declarations (not definitions) for the Interferogram to Spectrum abstract stage
 *
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 * based directly on the Scanning-HIS rsh2fbf application, written by Ray Garcia <rayg@ssec.wisc.edu>
 *
 *  \version $Id: Cifg2Spectrum.h,v 1.8 2005/07/08 07:12:52 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 *
 */

/**
 * \mainpage Converting Interferograms to Spectra
 *
 * \image html overview.jpg
 *
 * \image html capsule_diagram.jpg
 *
 */

#ifndef H_IFG2SPECTRUM
#define H_IFG2SPECTRUM

#ifndef NO_DEPENDENCY_INCLUDES
#include <complex>

// GIPS includes
#include "Physics.h"
#include "Instrument.h"
#include "ProtocolRole.h"
#include "Operator.h"

#include <boost/shared_ptr.hpp>

#endif

// NOTE: in the future, this file will be auto-generated by a flanging compiler.

namespace gips {

    class Cifg2Spectrum{
    public:
	struct settings_t {
	    instrument::uuid_t uuid;
	    unsigned int rawInterferogramSize; 
	    unsigned int shiftedInterferogramSize;
	    unsigned int doubledRawSpectrumSize; 
	    unsigned int rawSpectrumSize;
	    unsigned int chopRawSpectrumFrom; 
	    unsigned int chopRawSpectrumTo;
	    char wrapRawSpectrumLastPoint;
	};
	
	struct obs_in_t
	{
	    instrument::uuid_t uuid;
	    std::complex<double> rawInterferogram[2048];
	};

	struct obs_out_t
	{
	    instrument::uuid_t uuid;
	    std::complex<double> rawSpectrum[1025];
	};

	    struct Ports {
		Connector::InputPort<settings_t>& settings;
		Connector::InputPort<obs_in_t>& obs_in;
		Connector::OutputPort<obs_out_t>& obs_out;
		
		Ports(Connector::InputPort<settings_t>&,
		      Connector::InputPort<obs_in_t>&,
		      Connector::OutputPort<obs_out_t>&);
	    };
	    
	protected:    
	    Ports &ports;
	    
	public:
	    explicit Cifg2Spectrum(Ports&);
	    virtual Operator::Result operator()( ); ///< run this stage on input data provided over the ports.
	    virtual ~Cifg2Spectrum(); // abstract class
	    
	}; // class Ifg2Spectrum
    
} // namespace
#endif

