/*
 * \file Cfg2SpectrumTest.cc
 * \brief unit test for SHISStage subclass of Ifg2SpectrumStage
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 *  \version $Id: Cifg2SpectrumTest.cc,v 1.4 2005/07/08 20:21:48 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */

// C++ STL includes
#include <string>
#include <vector>
#include <iostream> // std::cerr

// GIPS framework includes
#include "Connector.h"
#include "Cifg2Spectrum_GIFTSv1.h"

using namespace std;
using namespace gips;
    
Operator::Result livelinessTest()
{
    Cifg2Spectrum::settings_t s_;
    s_.rawInterferogramSize = 2048;
    s_.shiftedInterferogramSize = 2048;
    s_.doubledRawSpectrumSize = 2048;
    s_.rawSpectrumSize = 1025;
    s_.chopRawSpectrumFrom = 1024;
    s_.chopRawSpectrumTo = 2048;
    s_.wrapRawSpectrumLastPoint = false;
    Connector::SimpleConnector<Cifg2Spectrum::settings_t> s(s_);
    
    Cifg2Spectrum::obs_in_t i_;
    Connector::SimpleConnector<Cifg2Spectrum::obs_in_t> i(i_);

    Cifg2Spectrum::obs_out_t o_;
    Connector::SimpleConnector<Cifg2Spectrum::obs_out_t> o(o_);
    
    // invoke operator with the correct ports
    Cifg2Spectrum::Ports ports(s,i,o);
    
    Ci2sImpl op(ports);
    Operator::Result res = op();
    
    return res;
}; // testOperator()


int main()
{
    Operator::Result rc;
    rc = livelinessTest();
    assert(rc == Operator::OK);
    return(0);
}

