/*
 * \brief SHIS implementation of Ifg2SpectrumStage
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 * based directly on the Scanning-HIS rsh2fbf application, written by Ray Garcia <rayg@ssec.wisc.edu>
 *
 *  \version $Id: Cifg2Spectrum_GIFTSv1.h,v 1.2 2005/07/08 07:12:52 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */

// NOTE: THIS FILE WILL BE AUTO-GENERATED IN THE FUTURE FROM INTEFACE DESCRIPTIONS
// OF THE SUBCAPSULES BY MEANS OF A FLANGING COMPILER

#include <complex>
#include <vector>

#include <boost/shared_ptr.hpp>

#include "Connector.h"
#include "IfgShift.h"
#include "CplxFFT.h"
#include "SpectrumChop.h"

#include "Cifg2Spectrum.h"

namespace gips {

// Ci2sImpl is an acronym for (C)omplex (i)nterferogram (to) (s)pectrum (Impl)emenatation
class Ci2sImpl: public Cifg2Spectrum
{
private:
    // intermediate buffers as connectors
    Connector::InputPortAdapter< Cifg2Spectrum::settings_t, IfgShift::settings_t > s1;
    Connector::InputPortAdapter< Cifg2Spectrum::settings_t, CplxFFT::settings_t > s2;
    Connector::InputPortAdapter< Cifg2Spectrum::settings_t, SpectrumChop::settings_t > s3;
    
    struct D1 {
	instrument::uuid_t uuid;
	std::complex<double> shiftedInterferogram[2048];
    } buffer_1;
    Connector::SimpleConnector<D1> bc1;

    struct D2 {
	instrument::uuid_t uuid;
	std::complex<double> doubledRawSpectrum[2048];
    } buffer_2;
    Connector::SimpleConnector<D2> bc2;
    
    Connector::InputPortAdapter< Cifg2Spectrum::obs_in_t, IfgShift::obs_in_t > d1i;
    Connector::OutputPortAdapter< D1, IfgShift::obs_out_t > d1o;
    
    Connector::InputPortAdapter< D1, CplxFFT::obs_in_t > d2i;
    Connector::OutputPortAdapter< D2, CplxFFT::obs_out_t > d2o;

    Connector::InputPortAdapter< D2, SpectrumChop::obs_in_t > d3i;
    Connector::OutputPortAdapter< Cifg2Spectrum::obs_out_t, SpectrumChop::obs_out_t > d3o;
    
    
    IfgShift::Ports ports1;    
    CplxFFT::Ports ports2;
    SpectrumChop::Ports ports3;

    IfgShift capsule1;
    CplxFFT capsule2;
    SpectrumChop capsule3;
    
public:
    explicit Ci2sImpl( Cifg2Spectrum::Ports &ports ): Cifg2Spectrum( ports ),

        s1(ports.settings), s2(ports.settings), s3(ports.settings),

        bc1(buffer_1), bc2(buffer_2),

	d1i(ports.obs_in), d1o(bc1), 
	d2i(bc1), d2o(bc2),
        d3i(bc2), d3o(ports.obs_out),
            
        ports1(s1, d1i, d1o),
        ports2(s2, d2i, d2o),
        ports3(s3, d3i, d3o),
      
        capsule1(ports1), capsule2(ports2), capsule3(ports3)
        {};  
    
    ~Ci2sImpl() {};
    Operator::Result operator() ( );
}; // class
    
} // Namespace
