/**
 * \file CplxFFT.h
 * \brief performs complex FFT
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 * based directly on the Scanning-HIS rsh2fbf application, written by Ray Garcia <rayg@ssec.wisc.edu>
 *
 *  \version $Id: CplxFFT.h,v 1.18 2005/07/08 07:12:52 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */

#ifndef H_CPLXFFT
#define H_CPLXFFT

#ifndef NO_DEPENDENCY_INCLUDES

// the FFTW system-dependent #include polka
#ifdef __APPLE__
#include "dfftw_threads.h"
#include "drfftw_threads.h"
#elif defined(__CYGWIN32__)
#include "fftw.h"
#include "rfftw.h"
#define fftw_threads_init() 
#define fftw_threads_one(a,b,c,d) fftw_one(b,c,d)
#define rfftw_threads_one(a,b,c,d) rfftw_one(b,c,d)
#else
#include "fftw_threads.h"
#include "rfftw_threads.h"
#endif

// GIPS includes
#include "Physics.h"
#include "Instrument.h"
#include "ProtocolRole.h"
#include "Operator.h"

#endif

// NOTE: this file will be auto-generated in the future.

namespace gips {
    
    class CplxFFT {
	
    public:
	struct settings_t 
	{
	    instrument::uuid_t uuid;
	    unsigned int unused_1;
	    unsigned int shiftedInterferogramSize;
	    unsigned int doubledRawSpectrumSize;
	    unsigned int unused_3;
	    unsigned int unused_4;
	    unsigned int unused_5;
	    char unused_6;
	}; 
	
	struct obs_in_t 
	{
	    instrument::uuid_t uuid;
	    complex<double> shiftedInterferogram[2048];
	};

	struct obs_out_t 
	{
	    instrument::uuid_t uuid;
	    complex<double> doubledRawSpectrum[2048];
	};
   
	struct Ports {
	    Connector::InputPort<settings_t>& settings;
	    Connector::InputPort<obs_in_t>& obs_in; 
	    Connector::OutputPort<obs_out_t>& obs_out;
	    
	    Ports(Connector::InputPort<settings_t>& settings_, 
		  Connector::InputPort<obs_in_t>& obs_in_,
		  Connector::OutputPort<obs_out_t>& obs_out_): 
		settings(settings_),
		obs_in(obs_in_),
		obs_out(obs_out_) {}
	  
	    ~Ports() {}
	};
	
    private:
	const Ports& ports;

	// FIXME - the below is not capable of being auto-generated, unless via a dirty hack.
	// some sort of pimpl or equivalent is called for, but what?
	fftw_plan plan; // cached machine-dependent plan - should it be const?
	
    public:
	explicit CplxFFT(Ports &); ///< ctor
	~CplxFFT(); ///< dtor
	Operator::Result operator() ( ); ///< make it so
    }; // class CplxFFT
    
} // namespace
#endif
    
    
