/*
 * \file IfgShiftTest.cc
 * \brief unit test for IfgShift operator
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 *  \version $Id: IfgShiftTest.cc,v 1.16 2005/07/08 07:12:52 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */


#include <iostream> // std::cerr
#include <complex>

#include "IfgShift.h"
#include "Connector.h"

using namespace gips;
using std::complex;



Operator::Result livenessTest()
{
    IfgShift::settings_t s_;
    s_.rawInterferogramSize = 2048;
    s_.shiftedInterferogramSize = 2048;
    Connector::SimpleConnector<IfgShift::settings_t> s(s_);

    IfgShift::obs_in_t i_;
    Connector::SimpleConnector<IfgShift::obs_in_t> i(i_);

    IfgShift::obs_out_t o_;
    Connector::SimpleConnector<IfgShift::obs_out_t> o(o_);


    // invoke operator with the correct ports
    IfgShift::Ports ports(s,i,o);

    IfgShift op(ports);
    Operator::Result res = op();
    
    return res;
}; // testOperator()


int main()
{
    Operator::Result rc = livenessTest();
    assert(rc == Operator::OK);
    return(0);
}

