/**
 * \file SpectrumChop.cc
 * \brief SHIS implementation of SpectrumFold operator
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 *  \version $Id: SpectrumChop.cc,v 1.6 2005/07/08 20:21:48 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */

#include "SpectrumChop.h"

using namespace gips;
using namespace std;

//#include <iostream> // DEBUG


SpectrumChop::Ports::Ports(Connector::InputPort<SpectrumChop::settings_t>& settings_, 
			   Connector::InputPort<SpectrumChop::obs_in_t>& obs_in_, 
			   Connector::OutputPort<SpectrumChop::obs_out_t>& obs_out_):
    settings(settings_), obs_in(obs_in_), obs_out(obs_out_) {}
SpectrumChop::Ports::~Ports() {}

SpectrumChop::SpectrumChop(SpectrumChop::Ports& p): ports(p) 
{
    // check consistency of symbols defined in settings. Namely:
    settings_t settings(ports.settings.getForInput());
    assert( settings.doubledRawSpectrumSize > settings.rawSpectrumSize );
    assert( settings.chopRawSpectrumFrom < settings.chopRawSpectrumTo );
    assert( settings.chopRawSpectrumTo <= settings.doubledRawSpectrumSize );
    assert( settings.rawSpectrumSize == settings.chopRawSpectrumTo - settings.chopRawSpectrumFrom + 1 );
}
SpectrumChop::~SpectrumChop() {}

Operator::Result SpectrumChop::operator()( )
{
    const settings_t settings(ports.settings.getForInput());

    const obs_in_t& obs_in(ports.obs_in.getForInput());
    const complex<double>* dataIn(&(obs_in.doubledRawSpectrum[0]));

    obs_out_t& obs_out(ports.obs_out.getForOutput());
    complex<double>* dataOut(&(obs_out.rawSpectrum[0]));

    // yes, I'm being a bad boy and copying data. boo hoo hoo.
    for (unsigned int src(settings.chopRawSpectrumFrom), dest(0); src < settings.chopRawSpectrumTo; ++src, ++dest)
    {
	dataOut[dest] = dataIn[src];
    };
    
    // curious case of the last point: wrap it, or zero?
    dataOut[settings.rawSpectrumSize - 1] = settings.wrapRawSpectrumLastPoint ? 
	dataIn[settings.chopRawSpectrumFrom] :
	0.0;

    //cerr << "SpectrumChop: dataOut@600: " << obs_out.rawSpectrum[600] << endl; // DEBUG 

    return Operator::OK;
}

