/**
 * \file SpectrumChop.h
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 *  \version $Id: SpectrumChop.h,v 1.5 2005/07/08 07:12:52 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  \endverbatim
 */

#ifndef H_SPECCHOP
#define H_SPECCHOP

#ifndef NO_DEPENDENCY_INCLUDES

#include "Physics.h"
#include "Instrument.h"
#include "ProtocolRole.h"
#include "Operator.h"
#include <complex>

#endif

// NOTE: This file is an example of the kind of output expected from the 
// GIPS flanging compiler, and will in the future NOT be generated by hand.
// As a result, all the input/output structs are Plain Old Data (POD)s,
// as indicated by the _t suffixes. Furthermore, all their members have
// names such as would be published in the global data dictionary.

namespace gips {
    class SpectrumChop {
	
    public:
	struct settings_t 
	{
	    instrument::uuid_t uuid;
	    unsigned int unused_1;
	    unsigned int unused_2;
	    unsigned int doubledRawSpectrumSize; 
	    unsigned int rawSpectrumSize;
	    unsigned int chopRawSpectrumFrom; 
	    unsigned int chopRawSpectrumTo;
	    char wrapRawSpectrumLastPoint;
	};
	
	struct obs_in_t 
	{
	    instrument::uuid_t uuid;
	    std::complex<double> doubledRawSpectrum[2044];
	};
	
	struct obs_out_t 
	{
	    instrument::uuid_t uuid;
	    std::complex<double> rawSpectrum[1025];
	};
	
	struct Ports {
	    Connector::InputPort<settings_t>& settings;
	    Connector::InputPort<obs_in_t>& obs_in;
	    Connector::OutputPort<obs_out_t>& obs_out;
	    
	    explicit Ports(Connector::InputPort<settings_t>&, 
			   Connector::InputPort<obs_in_t>&, 
			   Connector::OutputPort<obs_out_t>&);
	    ~Ports();
	};
	
    private:
	Ports &ports;
	
    public:
	explicit SpectrumChop(Ports&);
	Operator::Result operator()();
	~SpectrumChop();
    }; // class SpectrumChop
    
} // namespace


#endif
