/*
 * \file SpectrumChopTest.cc
 * \brief unit test for SpectrumChop operator
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 *  \version $Id: SpectrumChopTest.cc,v 1.4 2005/07/08 07:12:52 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */


#include <iostream>
#include <complex>

#include "SpectrumChop.h"
#include "Connector.h"

using std::complex;
using namespace gips;

const int INSIZE=2048;
const int OUTSIZE=1025;

void livenessTest()
{
  SpectrumChop::settings_t settings;
  settings.doubledRawSpectrumSize = 2048;
  settings.rawSpectrumSize = 1025;
  settings.chopRawSpectrumFrom = 1024;
  settings.chopRawSpectrumTo = 2048;
  settings.wrapRawSpectrumLastPoint = false;
  Connector::SimpleConnector<SpectrumChop::settings_t> testSettings(settings);

  SpectrumChop::obs_in_t obs_in;
  Connector::SimpleConnector<SpectrumChop::obs_in_t> testObs_in(obs_in);

  SpectrumChop::obs_out_t obs_out;
  Connector::SimpleConnector<SpectrumChop::obs_out_t> testObs_out(obs_out);

  SpectrumChop::Ports ports(testSettings, testObs_in, testObs_out);
  SpectrumChop schop(ports);

  Operator::Result res(schop());  // call

  assert(res == Operator::OK);
};

int main()
{
  livenessTest();
  return 0;
}
